﻿using Syncfusion.DocIO.DLS;
using System;
using System.ComponentModel;
using System.Drawing;
using System.Windows;

namespace CreateWordSample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }
        private void btnCreate_Click(object sender, RoutedEventArgs e)
        {
            //Creates a Word document
            WordDocument document = new WordDocument();
            //Add one section and one paragraph
            document.EnsureMinimal();
            //Append table into the Word document.
            IWTable table = document.LastSection.AddTable();
            table.ResetCells(4, 3);

            //Get the header row.
            WTableRow headerRow = table.FirstRow;
            headerRow.Height = 50;


            int i = 1;
            //Iterate cells in header row to set header content.
            foreach (WTableCell cell in headerRow.Cells)
            {
                //Set alignment for cell, to preserve image at the center
                cell.CellFormat.TextDirection = Syncfusion.DocIO.DLS.TextDirection.HorizontalFarEast;
                cell.CellFormat.VerticalAlignment = Syncfusion.DocIO.DLS.VerticalAlignment.Middle;
                //Create paragraph.
                IWParagraph paragraph = cell.AddParagraph();
                //Create an image with header contents.
                Image image = GetImage("Header " + i, new Font("Arial", 10));
                WPicture picture = paragraph.AppendPicture(image) as WPicture;
                //Set rotation to preserve text in defined angle.
                picture.Rotation = 315;
                i++;
            }
            //Saves the Word document
            document.Save("Result.docx");

            #region View the Workbook
            //Message box confirmation to view the created document.
            if (MessageBox.Show("Do you want to view the Word file?", "Word file has been created",
                    MessageBoxButton.YesNo, MessageBoxImage.Information) == MessageBoxResult.Yes)
            {
                try
                {
                    //Launching the Word file using the default Application.[Microsoft Word  Or Free WordViewer]
                    System.Diagnostics.Process.Start("Result.docx");

                    //Exit
                    Close();
                }
                catch (Win32Exception ex)
                {
                    Console.WriteLine(ex.ToString());
                }
            }
            else
                Close();
            #endregion
        }
        /// <summary>
        /// Get the image with text.
        /// </summary>
        private Image GetImage(string text, Font font)
        {
            //Create an bitmap image
            Bitmap bitmap = new Bitmap(80, 50);
            SizeF textsize;
            //Get the size of text.
            using (Graphics graphics = Graphics.FromImage(bitmap))
            {
                textsize = graphics.MeasureString(text, font);
            }
            //Create bitmap with text size
            bitmap = new Bitmap((int)textsize.Width, (int)textsize.Height);
            using (Graphics graphics = Graphics.FromImage(bitmap))
            {
                //Draw the text.
                graphics.DrawString(text, font, Brushes.Black, 0, 0);
            }
            return bitmap;
        }
    }
}

